NLSL: iterat Module Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- Modules List
- Module Members

Variables
iterat Module Reference

## Variables
integer, save | iter
integer, save | iwflag
double precision, save | fnorm
double precision, save | chisqr
double precision, save | rdchsq
double precision, save | ch2bnd
double precision, save | chnbnd
double precision, save | confid
double precision, save | delchi1
double precision, save | qfit
double precision, save | f2bnd
double precision, save | fnbnd
double precision, save | tbound
double precision, save | fnmin
logical, save | newitr
logical, save | covarok
logical, save | xreset

## Variable Documentation

double precision, save iterat::ch2bnd

Definition at line 15 of file iterat.f90.

double precision, save iterat::chisqr

Definition at line 15 of file iterat.f90.

double precision, save iterat::chnbnd

Definition at line 15 of file iterat.f90.

double precision, save iterat::confid

Definition at line 15 of file iterat.f90.

logical, save iterat::covarok

Definition at line 18 of file iterat.f90.

double precision, save iterat::delchi1

Definition at line 15 of file iterat.f90.

double precision, save iterat::f2bnd

Definition at line 15 of file iterat.f90.

double precision, save iterat::fnbnd

Definition at line 15 of file iterat.f90.

double precision, save iterat::fnmin

Definition at line 15 of file iterat.f90.

double precision, save iterat::fnorm

Definition at line 15 of file iterat.f90.

integer, save iterat::iter

Definition at line 14 of file iterat.f90.

integer, save iterat::iwflag

Definition at line 14 of file iterat.f90.

logical, save iterat::newitr

Definition at line 18 of file iterat.f90.

double precision, save iterat::qfit

Definition at line 15 of file iterat.f90.

double precision, save iterat::rdchsq

Definition at line 15 of file iterat.f90.

double precision, save iterat::tbound

Definition at line 15 of file iterat.f90.

logical, save iterat::xreset

Definition at line 18 of file iterat.f90.